# pyeon

The most advanced (and probably only) convienience store announcement generator!

## Usage

```python
import pyeon

pyeon.jeom()
```

## Why?

Why not?

## Credits

Phrases by spoqa creators.

Packaging idea by @nellag.
